# pyprelude

General-purpose Python support functions

## Install prerequisites

```
pip install setuptools-markdown
```

## Run tests

```
python.exe setup.py test
```

## Upload new versions to [PyPI][pypi]

```
python setup.py sdist upload
```

## Licence

[MIT License][licence]

Copyright &copy; 2017 Richard Cook

[licence]: LICENSE
[pypi]: https://pypi.python.org/pypi